# HOLY - atomic theme

This a startup theme for your project.

It respects Brad Frost atomic design:\
https://bradfrost.com/blog/post/atomic-web-design/


# DRUPAL WAY

- Holy theme is applicable to frontend project.
- Its based on the Classy theme.
- The goal is to style standard profile installation.


# GULP

You have to install Node JS (https://nodejs.org/en/) to your computer.

a, Go to theme folder, where `package.json` is located and install npm modules to your theme.

```bash
> npm install
```

b, compile sass to css

```bash
> gulp
```

# GULP LIBRARIES

```
"browserslist"
"gulp"
"gulp-autoprefixer"
"gulp-sass"
"gulp-sass-glob"
```

These are the basic npm components for compiling SASS to CSS.


# ATOMIC FOLDER

This folder structure is fundamental.\
It will help you respecting the atomic structure.

```
01-atoms
02-molecules
03-organisms
04-layouts
05-pages
```

# SASS COMPONENTS

```
[components]
    [01-atoms]
        _audio.scss
        _blockquote.scss
        _body.scss
        _form.scss
        _hr.scss
        _html.scss
        _img.scss
        _link.scss
        _list.scss
        _paragraph.scss
        _table.scss
        _title.scss
        _video.scss
    [02-molecules]
        [block]
            _block--breadcrumb.scss
        [field]
            _field--name-field-tags.scss
            _field--name-title.scss
            _field--type-comment.scss
            _field--type-image.scss
        [node]
            .gitkeep
        [view]  
            _view--frontpage.scss
        _block.scss
        _field.scss
        _menu.scss
        _messages.scss
        _node.scss
        _pager.scss
        _tabs.scss
        _view.scss
    [03-organisms]
        [copyright]
            .gitkeep
        [footer]
            _footer-block--branding.scss
            _footer-block--menu.scss
        [header]
            _header-block--branding.scss
            _header-block--language.scss
            _header-block--search.scss
        [hero]
            _hero-block--pagetitle.scss
        [main]
            _main-node--full.scss
            _main-node--teaser.scss
            _main-search--results.scss
            _main-user--login.scss
            _main-user--pass.scss
            _main-user--register.scss
        [menu]
            _menu-block--menu.scss
        [navbar]
            _navbar-block--branding.scss
            _navbar-icons.scss
        [sidebar]
            _sidebar-block--menu.scss
        _copyright.scss
        _footer.scss
        _header.scss
        _hero.scss
        _main.scss
        _menu.scss
        _navbar.scss
        _sidebar.scss
    [04-layouts]
        _body.scss
        _container.scss
        _layout.scss
        _navbar-collapse.scss
    [05-pages]
        _frontpage.scss
_class.scss
_color.scss
_fonts.scss
_global.scss
_variables.scss
ckeditor.scss
style.scss
```

# RULES

(1) FILES NAMING
----------------
Location determines file name

```
example:

a, _name.scss
b, _folder--name.scss
c, _folder-folder--name.scss
```

(2) FILE HEADER COMMENT
-----------------------
Location determines header comment

```
example:

a,
// 
// name 
// 

b,
// 
// FOLDER -- name 
// 

c,
// 
// FOLDER - FOLDER -- name 
// 
```

(3) FILE CONTENTS
-----------------
Location determines root selector

```
.name-selector {

  // any code

}

#folder {

    .name-selector {

      // any code

    }    

}
```

# STYLE.SCSS

NOTE:
- order is important for the function and priority of selectors
- gulp-sass-glob / first compile file, after folder content

```
@import 'fonts';
@import 'variables';
@import 'global';
@import 'class';

@import 'components/01-atoms/**/*';
@import 'components/02-molecules/**/*';
@import 'components/03-organisms/**/*';
@import 'components/04-layouts/**/*';
@import 'components/05-pages/**/*';
```

# CKEDITOR.SCSS

NOTE:
- order is important for the function and priority of selectors
- gulp-sass-glob / first compile file, after folder content

```
.cke_editable {
    padding: 25px;
}

@import 'fonts';
@import 'variables';
@import 'global';
@import 'class';

// components
@import 'components/01-atoms/typo';
```

# TEMPLATES

Holy respect classy base theme templates structure.\
It only fills new needed template.

